@@ -51,10 +51,9 @@ def text_decorate(string: str, decoration: str="BOLD"):
     endd = ansi["END"]
     return f"{text_dec}{string}{endd}"
 
-def get_funcs(ignore_char: str="_"):
+def get_funcs(all_funcs=globals().items() ignore_char: str="_"):
     funcs = []
-    r = list(globals().items()) + list(locals().items())
-    for key, value in r:
+    for key, value in all_funcs:
         if callable(value) and not re.match(f"^{ignore_char}.*", key):
             #if value.__module__ in [__name__, "__main__"]:
             funcs.append(value)
